@@ -22,4 +22,6 @@ def test_association(adata: AnnData, log_A: bool = False):
     # correct for zeros but setting them to the lowest value
     stats.loc[stats.fdr == 0, "fdr"] = stats.fdr[stats.fdr != 0].min()
     colors = ["red" if signi else "grey" for signi in stats.signi.values]
-    stats.plot.scatter(x="A", y="fdr", color=colors, logx=log_A, logy=True)
+    stats.plot.scatter(
+        x="A", y="fdr", color=colors, logx=log_A, logy=True, rasterized=True
+    )
